@@ -3,7 +3,7 @@
  * Horde_Service_Weather class for abstracting access to various weather
  * providers.
  *
- * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2016 Horde LLC (http://www.horde.org/)
  *
  * @author   Michael J Rubinsky <mrubinsk@horde.org>
  * @license  http://www.horde.org/licenses/bsd BSD
@@ -39,6 +39,7 @@ class Horde_Service_Weather
     const FORECAST_FIELD_WIND = 'wind';
     const FORECAST_FIELD_PRECIPITATION = 'pop';
     const FORECAST_FIELD_HUMIDITY = 'humidity';
+    const FORECAST_FIELD_ACCUMULATION = 'accum';
 
     /** Unit constants **/
     const UNITS_STANDARD = 1;
@@ -56,4 +57,20 @@ class Horde_Service_Weather
     const SEARCHTYPE_ZIP = 3;
     const SEARCHTYPE_CITYSTATE = 4;
 
+    /**
+     * Utility function to return textual cardinal compass directions from degress.
+     *
+     * @param integer $degree  The degree direction (0 - 360).
+     *
+     * @return string  The cardinal direction.
+     * @since 2.3.0
+     */
+    public static function degToDirection($degree)
+    {
+        $cardinal = array('N', 'NNE', 'NE', 'ENE', 'E', 'ESE', 'SE', 'SSE', 'S', 'SSW', 'SW', 'WSW', 'W', 'WNW', 'NW', 'NNW');
+        $deg_delta = (int)($degree/22.5 + .5);
+
+        return $cardinal[$deg_delta % 16];
+    }
+
 }
\ No newline at end of file
